@@ -226,21 +226,14 @@ class Feature(ABC):
         in the meta_data dictionary. It returns the input value if valid
         otherwise raises a proper exepction."""
 
-    def check_meta_data_attr(self) -> None:
-        """An internal method called before returning the validator."""
-        if self.meta_data is None:
-            raise FeatureMetaDataMissing(
-                name=self.name,
-                message="Not possible to return a validator for 'meta_data = None'.",
-            )
-
     def get_validator(self) -> pydantic.validator:
         """A method used to return the validator of a given feature."""
         val_args: Dict = {"pre": True, "each_item": True, "allow_reuse": True}
 
-        self.check_meta_data_attr()
-
-        return pydantic.validator(self.name, **val_args)(self.validate_func)
+        if self.meta_data:
+            return pydantic.validator(self.name, **val_args)(self.validate_func)
+        else:
+            return None
 
 
 @dataclass
@@ -250,16 +243,21 @@ class IntegerFeature(Feature):
     feature_type: "FeatureType" = FeatureType.INT
 
     def describe_func(
-        self, x: Union[pd.Series, np.ndarray], x_percentile: float = 0.95
+        self, x: Union[pd.Series, np.ndarray, list], x_percentile: float = 0.95
     ) -> None:
         """This method is used to update the meta_data dictionary for the
         default integer feature validation.
 
         Args:
-            x (pd.Series): A pandas series with integer (or float) values.
+            x (pd.Series, np.ndarray, list): A list of numbers.
             x_percentile (float, optional): The percentile we want to use as a
             warning level. Defaults to 0.95.
         """
+        if not isinstance(x, (pd.Series, np.ndarray, list)):
+            raise TypeError(
+                f"The input argument 'x' must be a pandas Series, numpy array or list."
+                f" The input argument is of type {type(x)}."
+            )
 
         warn_low, warn_high = np.percentile(
             x,
@@ -272,8 +270,8 @@ class IntegerFeature(Feature):
         self.meta_data = {
             "warn_low": warn_low,
             "warn_high": warn_high,
-            "skip_low": x.min(),
-            "skip_high": x.max(),
+            "skip_low": min(x),
+            "skip_high": max(x),
         }
 
     def validate_func(self, v: Union[int, float]) -> Union[int, float]:
